@@ -2,7 +2,7 @@
 /**
  * Turba directory driver implementation for PHP's LDAP extension.
  *
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -229,9 +229,11 @@ class Turba_Driver_Ldap extends Turba_Driver
      * @return array  Hash containing the search results.
      * @throws Horde_Exception_NotFound
      */
-    protected function _read($key, $ids, $owner, array $fields,
-                             array $blobFields = array(),
-                             array $dateFields = array())
+    protected function _read(
+        $key, $ids, $owner, array $fields,
+        array $blobFields = array(),
+        array $dateFields = array()
+    )
     {
         /* Only DN. */
         if ($key != 'dn') {
@@ -241,7 +243,7 @@ class Turba_Driver_Ldap extends Turba_Driver
         $this->_connect();
 
         if (empty($this->_params['objectclass'])) {
-            $filter = null;
+            $filter = 'objectclass=*';
         } else {
             $filter = (string)Horde_Ldap_Filter::build(array('objectclass' => $this->_params['objectclass']), 'or');
         }
@@ -382,7 +384,7 @@ class Turba_Driver_Ldap extends Turba_Driver
          * values. These are needed so that we can delete any
          * attributes that have been removed by using ldap_mod_del. */
         if (empty($this->_params['objectclass'])) {
-            $filter = null;
+            $filter = 'objectclass=*';
         } else {
             $filter = (string)Horde_Ldap_Filter::build(array('objectclass' => $this->_params['objectclass']), 'or');
         }
@@ -538,13 +540,13 @@ class Turba_Driver_Ldap extends Turba_Driver
      * @param resource $res     Result identifier.
      *
      * @return array  Hash containing the results.
-     * @throws Turba_Exception
+     * @throws Horde_Exception_NotFound
      */
     protected function _getResults(array $fields, $res)
     {
         $entries = @ldap_get_entries($this->_ds, $res);
         if ($entries === false) {
-            throw new Turba_Exception(sprintf(_("Read failed: (%s) %s"), ldap_errno($this->_ds), ldap_error($this->_ds)));
+            throw new Horde_Exception_NotFound(sprintf(_("Read failed: (%s) %s"), ldap_errno($this->_ds), ldap_error($this->_ds)));
         }
 
         /* Return only the requested fields (from $fields, above). */
